pub struct OfflineProxy<'p>(/* private fields */);Implementations
Sourceimpl<'p> OfflineProxy<'p>
impl<'p> OfflineProxy<'p>
Sourcepub async fn new(conn: &Connection) -> Result<OfflineProxy<'p>>
pub async fn new(conn: &Connection) -> Result<OfflineProxy<'p>>
Creates a new proxy with the default service and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
Sourcepub async fn clear_results(&self) -> Result<()>
pub async fn clear_results(&self) -> Result<()>
ClearResults method
Sourcepub async fn get_prepared(&self) -> Result<Vec<String>>
pub async fn get_prepared(&self) -> Result<Vec<String>>
GetPrepared method
Sourcepub async fn trigger_upgrade(&self, action: &str) -> Result<()>
pub async fn trigger_upgrade(&self, action: &str) -> Result<()>
TriggerUpgrade method
Sourcepub async fn prepared_upgrade(&self) -> Result<HashMap<String, OwnedValue>>
pub async fn prepared_upgrade(&self) -> Result<HashMap<String, OwnedValue>>
PreparedUpgrade property
Sourcepub fn cached_prepared_upgrade(
&self,
) -> Result<Option<<Result<HashMap<String, OwnedValue>> as ResultAdapter>::Ok>, <Result<HashMap<String, OwnedValue>> as ResultAdapter>::Err>
pub fn cached_prepared_upgrade( &self, ) -> Result<Option<<Result<HashMap<String, OwnedValue>> as ResultAdapter>::Ok>, <Result<HashMap<String, OwnedValue>> as ResultAdapter>::Err>
PreparedUpgrade property
Get the cached value of the PreparedUpgrade property, or None if the property is not cached.
Sourcepub async fn receive_prepared_upgrade_changed(
&self,
) -> PropertyStream<'p, <Result<HashMap<String, OwnedValue>> as ResultAdapter>::Ok>
pub async fn receive_prepared_upgrade_changed( &self, ) -> PropertyStream<'p, <Result<HashMap<String, OwnedValue>> as ResultAdapter>::Ok>
PreparedUpgrade property
Create a stream for the PreparedUpgrade property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn trigger_action(&self) -> Result<String>
pub async fn trigger_action(&self) -> Result<String>
TriggerAction property
Sourcepub fn cached_trigger_action(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_trigger_action( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
TriggerAction property
Get the cached value of the TriggerAction property, or None if the property is not cached.
Sourcepub async fn receive_trigger_action_changed(
&self,
) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
pub async fn receive_trigger_action_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
TriggerAction property
Create a stream for the TriggerAction property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn update_prepared(&self) -> Result<bool>
pub async fn update_prepared(&self) -> Result<bool>
UpdatePrepared property
Sourcepub fn cached_update_prepared(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_update_prepared( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
UpdatePrepared property
Get the cached value of the UpdatePrepared property, or None if the property is not cached.
Sourcepub async fn receive_update_prepared_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_update_prepared_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
UpdatePrepared property
Create a stream for the UpdatePrepared property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn update_triggered(&self) -> Result<bool>
pub async fn update_triggered(&self) -> Result<bool>
UpdateTriggered property
Sourcepub fn cached_update_triggered(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_update_triggered( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
UpdateTriggered property
Get the cached value of the UpdateTriggered property, or None if the property is not cached.
Sourcepub async fn receive_update_triggered_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_update_triggered_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
UpdateTriggered property
Create a stream for the UpdateTriggered property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn upgrade_prepared(&self) -> Result<bool>
pub async fn upgrade_prepared(&self) -> Result<bool>
UpgradePrepared property
Sourcepub fn cached_upgrade_prepared(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_upgrade_prepared( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
UpgradePrepared property
Get the cached value of the UpgradePrepared property, or None if the property is not cached.
Sourcepub async fn receive_upgrade_prepared_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_upgrade_prepared_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
UpgradePrepared property
Create a stream for the UpgradePrepared property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn upgrade_triggered(&self) -> Result<bool>
pub async fn upgrade_triggered(&self) -> Result<bool>
UpgradeTriggered property
Sourcepub fn cached_upgrade_triggered(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_upgrade_triggered( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
UpgradeTriggered property
Get the cached value of the UpgradeTriggered property, or None if the property is not cached.
Sourcepub async fn receive_upgrade_triggered_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_upgrade_triggered_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
UpgradeTriggered property
Create a stream for the UpgradeTriggered property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.