PackageKitProxy

Struct PackageKitProxy 

pub struct PackageKitProxy<'p>(/* private fields */);

Implementations

Source

impl<'p> PackageKitProxy<'p>

pub async fn new(conn: &Connection) -> Result<PackageKitProxy<'p>>

Creates a new proxy with the default service and path.

pub fn builder(conn: &Connection) -> Builder<'p, Self>

Returns a customizable builder for this proxy.

pub fn into_inner(self) -> Proxy<'p>

Consumes self, returning the underlying zbus::Proxy.

pub fn inner(&self) -> &Proxy<'p>

The reference to the underlying zbus::Proxy.

pub fn inner_mut(&mut self) -> &mut Proxy<'p>

The mutable reference to the underlying zbus::Proxy.

pub async fn can_authorize(&self, action_id: &str) -> Result<u32>

CanAuthorize method

pub async fn create_transaction(&self) -> Result<OwnedObjectPath>

CreateTransaction method

pub async fn get_daemon_state(&self) -> Result<String>

GetDaemonState method

pub async fn get_package_history( &self, names: &[&str], count: u32, ) -> Result<HashMap<String, Vec<HashMap<String, OwnedValue>>>>

GetPackageHistory method

pub async fn get_time_since_action(&self, role: u32) -> Result<u32>

GetTimeSinceAction method

pub async fn get_transaction_list(&self) -> Result<Vec<OwnedObjectPath>>

GetTransactionList method

pub async fn set_proxy( &self, proxy_http: &str, proxy_https: &str, proxy_ftp: &str, proxy_socks: &str, no_proxy: &str, pac: &str, ) -> Result<()>

SetProxy method

pub async fn state_has_changed(&self, reason: &str) -> Result<()>

StateHasChanged method

pub async fn suggest_daemon_quit(&self) -> Result<()>

SuggestDaemonQuit method

pub async fn receive_repo_list_changed(&self) -> Result<RepoListChangedStream>

Create a stream that receives RepoListChanged signals.

This a convenient wrapper around zbus::Proxy::receive_signal. RepoListChanged signal

pub async fn receive_restart_schedule(&self) -> Result<RestartScheduleStream>

Create a stream that receives RestartSchedule signals.

This a convenient wrapper around zbus::Proxy::receive_signal. RestartSchedule signal

pub async fn receive_transaction_list_changed( &self, ) -> Result<TransactionListChangedStream>

Create a stream that receives TransactionListChanged signals.

This a convenient wrapper around zbus::Proxy::receive_signal. TransactionListChanged signal

pub async fn receive_transaction_list_changed_with_args( &self, args: &[(u8, &str)], ) -> Result<TransactionListChangedStream>

Create a stream that receives TransactionListChanged signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. TransactionListChanged signal

pub async fn receive_updates_changed(&self) -> Result<UpdatesChangedStream>

Create a stream that receives UpdatesChanged signals.

This a convenient wrapper around zbus::Proxy::receive_signal. UpdatesChanged signal

pub async fn backend_author(&self) -> Result<String>

BackendAuthor property

pub fn cached_backend_author( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

BackendAuthor property Get the cached value of the BackendAuthor property, or None if the property is not cached.

pub async fn receive_backend_author_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>

BackendAuthor property Create a stream for the BackendAuthor property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn backend_description(&self) -> Result<String>

BackendDescription property

pub fn cached_backend_description( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

BackendDescription property Get the cached value of the BackendDescription property, or None if the property is not cached.

pub async fn receive_backend_description_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>

BackendDescription property Create a stream for the BackendDescription property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn backend_name(&self) -> Result<String>

BackendName property

pub fn cached_backend_name( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

BackendName property Get the cached value of the BackendName property, or None if the property is not cached.

pub async fn receive_backend_name_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>

BackendName property Create a stream for the BackendName property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn distro_id(&self) -> Result<String>

DistroId property

pub fn cached_distro_id( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

DistroId property Get the cached value of the DistroId property, or None if the property is not cached.

pub async fn receive_distro_id_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>

DistroId property Create a stream for the DistroId property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn filters(&self) -> Result<u64>

Filters property

pub fn cached_filters( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Filters property Get the cached value of the Filters property, or None if the property is not cached.

pub async fn receive_filters_changed( &self, ) -> PropertyStream<'p, <Result<u64> as ResultAdapter>::Ok>

Filters property Create a stream for the Filters property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn groups(&self) -> Result<u64>

Groups property

pub fn cached_groups( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Groups property Get the cached value of the Groups property, or None if the property is not cached.

pub async fn receive_groups_changed( &self, ) -> PropertyStream<'p, <Result<u64> as ResultAdapter>::Ok>

Groups property Create a stream for the Groups property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn locked(&self) -> Result<bool>

Locked property

pub fn cached_locked( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Locked property Get the cached value of the Locked property, or None if the property is not cached.

pub async fn receive_locked_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

Locked property Create a stream for the Locked property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn mime_types(&self) -> Result<Vec<String>>

MimeTypes property

pub fn cached_mime_types( &self, ) -> Result<Option<<Result<Vec<String>> as ResultAdapter>::Ok>, <Result<Vec<String>> as ResultAdapter>::Err>

MimeTypes property Get the cached value of the MimeTypes property, or None if the property is not cached.

pub async fn receive_mime_types_changed( &self, ) -> PropertyStream<'p, <Result<Vec<String>> as ResultAdapter>::Ok>

MimeTypes property Create a stream for the MimeTypes property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn network_state(&self) -> Result<u32>

NetworkState property

pub fn cached_network_state( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>

NetworkState property Get the cached value of the NetworkState property, or None if the property is not cached.

pub async fn receive_network_state_changed( &self, ) -> PropertyStream<'p, <Result<u32> as ResultAdapter>::Ok>

NetworkState property Create a stream for the NetworkState property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn roles(&self) -> Result<u64>

Roles property

pub fn cached_roles( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Roles property Get the cached value of the Roles property, or None if the property is not cached.

pub async fn receive_roles_changed( &self, ) -> PropertyStream<'p, <Result<u64> as ResultAdapter>::Ok>

Roles property Create a stream for the Roles property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn version_major(&self) -> Result<u32>

VersionMajor property

pub fn cached_version_major( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>

VersionMajor property Get the cached value of the VersionMajor property, or None if the property is not cached.

pub async fn receive_version_major_changed( &self, ) -> PropertyStream<'p, <Result<u32> as ResultAdapter>::Ok>

VersionMajor property Create a stream for the VersionMajor property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn version_micro(&self) -> Result<u32>

VersionMicro property

pub fn cached_version_micro( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>

VersionMicro property Get the cached value of the VersionMicro property, or None if the property is not cached.

pub async fn receive_version_micro_changed( &self, ) -> PropertyStream<'p, <Result<u32> as ResultAdapter>::Ok>

VersionMicro property Create a stream for the VersionMicro property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn version_minor(&self) -> Result<u32>

VersionMinor property

pub fn cached_version_minor( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>

VersionMinor property Get the cached value of the VersionMinor property, or None if the property is not cached.

pub async fn receive_version_minor_changed( &self, ) -> PropertyStream<'p, <Result<u32> as ResultAdapter>::Ok>

VersionMinor property Create a stream for the VersionMinor property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.