pub struct PackageKitProxyBlocking<'p>(/* private fields */);Implementations
Sourceimpl<'p> PackageKitProxyBlocking<'p>
impl<'p> PackageKitProxyBlocking<'p>
Sourcepub fn new(conn: &Connection) -> Result<PackageKitProxyBlocking<'p>>
pub fn new(conn: &Connection) -> Result<PackageKitProxyBlocking<'p>>
Creates a new proxy with the default service and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
CanAuthorize method
Sourcepub fn create_transaction(&self) -> Result<OwnedObjectPath>
pub fn create_transaction(&self) -> Result<OwnedObjectPath>
CreateTransaction method
Sourcepub fn get_daemon_state(&self) -> Result<String>
pub fn get_daemon_state(&self) -> Result<String>
GetDaemonState method
Sourcepub fn get_package_history(
&self,
names: &[&str],
count: u32,
) -> Result<HashMap<String, Vec<HashMap<String, OwnedValue>>>>
pub fn get_package_history( &self, names: &[&str], count: u32, ) -> Result<HashMap<String, Vec<HashMap<String, OwnedValue>>>>
GetPackageHistory method
Sourcepub fn get_time_since_action(&self, role: u32) -> Result<u32>
pub fn get_time_since_action(&self, role: u32) -> Result<u32>
GetTimeSinceAction method
Sourcepub fn get_transaction_list(&self) -> Result<Vec<OwnedObjectPath>>
pub fn get_transaction_list(&self) -> Result<Vec<OwnedObjectPath>>
GetTransactionList method
Sourcepub fn set_proxy(
&self,
proxy_http: &str,
proxy_https: &str,
proxy_ftp: &str,
proxy_socks: &str,
no_proxy: &str,
pac: &str,
) -> Result<()>
pub fn set_proxy( &self, proxy_http: &str, proxy_https: &str, proxy_ftp: &str, proxy_socks: &str, no_proxy: &str, pac: &str, ) -> Result<()>
SetProxy method
Sourcepub fn state_has_changed(&self, reason: &str) -> Result<()>
pub fn state_has_changed(&self, reason: &str) -> Result<()>
StateHasChanged method
Sourcepub fn suggest_daemon_quit(&self) -> Result<()>
pub fn suggest_daemon_quit(&self) -> Result<()>
SuggestDaemonQuit method
Sourcepub fn receive_repo_list_changed(&self) -> Result<RepoListChangedIterator>
pub fn receive_repo_list_changed(&self) -> Result<RepoListChangedIterator>
Create a stream that receives RepoListChanged signals.
This a convenient wrapper around zbus::blocking::Proxy::receive_signal.
RepoListChanged signal
Sourcepub fn receive_restart_schedule(&self) -> Result<RestartScheduleIterator>
pub fn receive_restart_schedule(&self) -> Result<RestartScheduleIterator>
Create a stream that receives RestartSchedule signals.
This a convenient wrapper around zbus::blocking::Proxy::receive_signal.
RestartSchedule signal
Sourcepub fn receive_transaction_list_changed(
&self,
) -> Result<TransactionListChangedIterator>
pub fn receive_transaction_list_changed( &self, ) -> Result<TransactionListChangedIterator>
Create a stream that receives TransactionListChanged signals.
This a convenient wrapper around zbus::blocking::Proxy::receive_signal.
TransactionListChanged signal
Sourcepub fn receive_transaction_list_changed_with_args(
&self,
args: &[(u8, &str)],
) -> Result<TransactionListChangedIterator>
pub fn receive_transaction_list_changed_with_args( &self, args: &[(u8, &str)], ) -> Result<TransactionListChangedIterator>
Create a stream that receives TransactionListChanged signals.
This a convenient wrapper around zbus::blocking::Proxy::receive_signal_with_args.
TransactionListChanged signal
Sourcepub fn receive_updates_changed(&self) -> Result<UpdatesChangedIterator>
pub fn receive_updates_changed(&self) -> Result<UpdatesChangedIterator>
Create a stream that receives UpdatesChanged signals.
This a convenient wrapper around zbus::blocking::Proxy::receive_signal.
UpdatesChanged signal
BackendAuthor property
BackendAuthor property
Get the cached value of the BackendAuthor property, or None if the property is not cached.
BackendAuthor property
Create a stream for the BackendAuthor property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn backend_description(&self) -> Result<String>
pub fn backend_description(&self) -> Result<String>
BackendDescription property
Sourcepub fn cached_backend_description(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_backend_description( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
BackendDescription property
Get the cached value of the BackendDescription property, or None if the property is not cached.
Sourcepub fn receive_backend_description_changed(
&self,
) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
pub fn receive_backend_description_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
BackendDescription property
Create a stream for the BackendDescription property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn backend_name(&self) -> Result<String>
pub fn backend_name(&self) -> Result<String>
BackendName property
Sourcepub fn cached_backend_name(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_backend_name( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
BackendName property
Get the cached value of the BackendName property, or None if the property is not cached.
Sourcepub fn receive_backend_name_changed(
&self,
) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
pub fn receive_backend_name_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
BackendName property
Create a stream for the BackendName property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_distro_id(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_distro_id( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
DistroId property
Get the cached value of the DistroId property, or None if the property is not cached.
Sourcepub fn receive_distro_id_changed(
&self,
) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
pub fn receive_distro_id_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
DistroId property
Create a stream for the DistroId property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_filters(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_filters( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
Filters property
Get the cached value of the Filters property, or None if the property is not cached.
Sourcepub fn receive_filters_changed(
&self,
) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
pub fn receive_filters_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
Filters property
Create a stream for the Filters property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_groups(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_groups( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
Groups property
Get the cached value of the Groups property, or None if the property is not cached.
Sourcepub fn receive_groups_changed(
&self,
) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
pub fn receive_groups_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
Groups property
Create a stream for the Groups property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_locked(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_locked( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
Locked property
Get the cached value of the Locked property, or None if the property is not cached.
Sourcepub fn receive_locked_changed(
&self,
) -> PropertyIterator<'p, <Result<bool> as ResultAdapter>::Ok>
pub fn receive_locked_changed( &self, ) -> PropertyIterator<'p, <Result<bool> as ResultAdapter>::Ok>
Locked property
Create a stream for the Locked property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn mime_types(&self) -> Result<Vec<String>>
pub fn mime_types(&self) -> Result<Vec<String>>
MimeTypes property
Sourcepub fn cached_mime_types(
&self,
) -> Result<Option<<Result<Vec<String>> as ResultAdapter>::Ok>, <Result<Vec<String>> as ResultAdapter>::Err>
pub fn cached_mime_types( &self, ) -> Result<Option<<Result<Vec<String>> as ResultAdapter>::Ok>, <Result<Vec<String>> as ResultAdapter>::Err>
MimeTypes property
Get the cached value of the MimeTypes property, or None if the property is not cached.
Sourcepub fn receive_mime_types_changed(
&self,
) -> PropertyIterator<'p, <Result<Vec<String>> as ResultAdapter>::Ok>
pub fn receive_mime_types_changed( &self, ) -> PropertyIterator<'p, <Result<Vec<String>> as ResultAdapter>::Ok>
MimeTypes property
Create a stream for the MimeTypes property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn network_state(&self) -> Result<u32>
pub fn network_state(&self) -> Result<u32>
NetworkState property
Sourcepub fn cached_network_state(
&self,
) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
pub fn cached_network_state( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
NetworkState property
Get the cached value of the NetworkState property, or None if the property is not cached.
Sourcepub fn receive_network_state_changed(
&self,
) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
pub fn receive_network_state_changed( &self, ) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
NetworkState property
Create a stream for the NetworkState property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_roles(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_roles( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
Roles property
Get the cached value of the Roles property, or None if the property is not cached.
Sourcepub fn receive_roles_changed(
&self,
) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
pub fn receive_roles_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
Roles property
Create a stream for the Roles property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn version_major(&self) -> Result<u32>
pub fn version_major(&self) -> Result<u32>
VersionMajor property
Sourcepub fn cached_version_major(
&self,
) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
pub fn cached_version_major( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
VersionMajor property
Get the cached value of the VersionMajor property, or None if the property is not cached.
Sourcepub fn receive_version_major_changed(
&self,
) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
pub fn receive_version_major_changed( &self, ) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
VersionMajor property
Create a stream for the VersionMajor property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn version_micro(&self) -> Result<u32>
pub fn version_micro(&self) -> Result<u32>
VersionMicro property
Sourcepub fn cached_version_micro(
&self,
) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
pub fn cached_version_micro( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
VersionMicro property
Get the cached value of the VersionMicro property, or None if the property is not cached.
Sourcepub fn receive_version_micro_changed(
&self,
) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
pub fn receive_version_micro_changed( &self, ) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
VersionMicro property
Create a stream for the VersionMicro property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn version_minor(&self) -> Result<u32>
pub fn version_minor(&self) -> Result<u32>
VersionMinor property
Sourcepub fn cached_version_minor(
&self,
) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
pub fn cached_version_minor( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
VersionMinor property
Get the cached value of the VersionMinor property, or None if the property is not cached.
Sourcepub fn receive_version_minor_changed(
&self,
) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
pub fn receive_version_minor_changed( &self, ) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
VersionMinor property
Create a stream for the VersionMinor property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.